@@ -2,7 +2,7 @@ from unittest import mock
 
 import pytest
 
-from alive_progress.core.progress import _render_title
+from alive_progress.core.progress import _GatedAssignProperty, _GatedProperty, _render_title
 from alive_progress.utils.cells import join_cells
 
 
@@ -28,3 +28,27 @@ from alive_progress.utils.cells import join_cells
 def test_render_title(length, text, expected):
     local_config = mock.Mock(title=text, title_length=length)
     assert join_cells(_render_title(local_config)) == expected
+
+
+def test_gated_properties():
+    class AClass:
+        readonly = _GatedProperty()
+        assignable = _GatedAssignProperty()
+
+    instance, m = AClass(), mock.Mock()
+    instance._handle = True
+    instance._readonly = lambda: 1
+    instance._assignable = m
+
+    assert instance.readonly() == 1
+
+    instance.assignable()
+    m.assert_called_once_with()
+
+    m.reset_mock()
+    instance.assignable(2)
+    m.assert_called_once_with(2)
+
+    m.reset_mock()
+    instance.assignable = 3
+    m.assert_called_once_with(3)
